get.sensitivity.obj <- function(lprec) {
  .Call(RlpSolve_get_sensitivity_obj, lprec)
}
